@@ -10,3 +10,5 @@ class DarkModePatch(BasePatch):
         app.add_css_file(filename="fix_dropdown_style.css")
         app.add_css_file(filename="fix_code_header_style.css")
         app.add_css_file(filename="fix_sidebar_scroll.css")
+        app.add_css_file(filename="fix_margin.css")
+        app.add_css_file(filename="fix_align_text_captions.css")
